<TS language="eu" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Sortu helbide berria</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Berria</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopiatu hautatutako helbidea sistemaren arbelean</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiatu</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Itxi</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Ezabatu aukeratutako helbideak listatik</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Bilatzeko, helbide edo etiketa sartu</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Uneko fitxategian datuak esportatu</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Esportatu</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Ezabatu</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Dirua bidaltzeko helbidea hautatu</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Dirua jasotzeko helbidea hautatu</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Aukeratu</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Helbideak bidaltzen</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Helbideak jasotzen</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Hauek dira zuk dirua jaso dezaketen Bitcoin helbideak. Egiaztatu beti diru-kopurua eta dirua jasoko duen helbidea zuzen egon daitezen, txanponak bidali baino lehen.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Etiketa &amp;Kopiatu</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editatu</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Helbide lista esportatu</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Komaz bereizitako artxiboa (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Esportazioak huts egin du</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Akats bat egon da helbide lista %1-ean gordetzen sahiatzean. Mesedez, saiatu berriro.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Izendapen</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Helbidea</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(izendapenik ez)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Pasahitzaren dialogoa</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Pasahitza sartu</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Pasahitz berria</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Pasahitz berria errepiikatu</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Pasahitza erakutsi</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Diruzorroa enkriptatu</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Diruzorroaren pasahitza behar du eragiketa honek, diruzorroa desblokeatzeko.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Diruzorroa desblokeatu</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Eragiketa honek zure diruzorroaren pasahitza behar du, diruzorroa desenkriptatzeko.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Diruzorroa desenkriptatu</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Pasahitza aldatu</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Diruorroaren enkriptazioa berretsi</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Abisua: Diruzorroa enkriptatzen baduzu eta zure pasahitza galtzen baduzu, &lt;b&gt;BITCOIN GUZTIAK GALDUKO DITUZU&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Seguru al zaude, zure diruzorroa enkriptatu nahi duzula?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Zorroa enkriptatuta</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Diruzorroaren pasahitz berria sartu. &lt;br/&gt;Mesedez &lt;b&gt; hamar edo gehiago ausazko hizkiko&lt;/b&gt; pasahitza erabili, edo &lt;b&gt; gutxienez zortzi hitz&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Diruzorroaren pasahitz zahar zein berria sartu.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>Gogoan izan diruzorroaren enkripzioak ezin dituela zure bitcoinak zure ordenagailuan izan dezakezun malware batengandik lapurtuak izatetik guztiz babestu .</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>Enkriptatzeko diruzorroa</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>Zure diruzorroa enkriptatzekotan dago</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>Zure diruzorroa enkriptatua dago orain.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>GARRANTZITSUA: Diruzorroaren segurtasun-kopia, wallet.dat, erabilezina bihurtuko da enkriptazioa burutu ondoren. Ondorioz, segurtasun-kopia berriekin ordezkatu beharko zenituzke zure jada eginik dituzun diruzorroaren kopiak.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Diruzorroaren enkriptazioak huts egin du</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Diruzorroaren enkriptazioak huts egin du barne-akats baten ondorioz. Zure diruzorroa ez da enkriptatu.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Eman dituzun pasahitzak ez datoz bat.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Zorroaren desblokeoak huts egin du</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Zorroa desenkriptatzeko sartutako pasahitza okerra da.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Zorroaren desenkriptazioak huts egin du</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Diruzorroaren pasahitza arrakastaz aldatu da.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Abisua: Mayuskulak blokeatuak dituzu!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Saremaskara</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Honarte debekatua </translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;Mezua zinatu</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Sarearekin sinkronizatzen...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Gainbegiratu</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Diruzorroaren begirada orokorra ikusi</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transakzioak</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Ikusi transakzioen historia</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Irten</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Aplikaziotik irten</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>%1-ri buruz</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>%1-ri buruzko informazioa azaldu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt-ri buruz</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Erakutsi Qt-ren buruzko informazioa</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Aukerak...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>%1-ren konfiguraketa aukerak aldatu</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Diruzorroa &amp;enkriptatu...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Diruzorroaren kopia bat gorde</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Pasahitza &amp;aldatu...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>&amp;URLa zabaldu</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>Diruzorroa sortu...</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>Diruzorro berri bat sortu</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Diruzorroa:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation>Sarea desaktibatua</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Burukoak sinkronizatzen (%1)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Blokeak diskoan berriro zerrendatzen...</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation>Proxya &lt;b&gt;gaituta&lt;/b&gt; dago : %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Bidali txanponak Bitcoin helbide batera</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Diru-zorroaren segurtasun-kopia beste leku batean.</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Diruzorroa enkriptatzeko erabilitako pasahitza aldatu</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Mezua &amp;balioztatu...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Bidali</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Jaso</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Erakutsi / Izkutatu</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Lehio nagusia erakutsi edo izkutatu</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Zure diru-zorroari dagozkion giltza pribatuak enkriptatu.</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Sinatu mezuak Bitcoinen helbideekin, zure jabea zarela frogatzeko.</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Egiaztatu mesua Bitcoin helbide espezifikoarekin erregistratu direla ziurtatzeko</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Artxiboa</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ezarpenak</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Laguntza</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Fitxen tresna-barra</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Erakutsi bidalketa-helbideen eta etiketen zerrenda</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Harrera-helbideen eta etiketen zerrenda erakutsi</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Komando-lerroaren aukerak</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Blokeak diskoan indexatzen...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Blokeak diskoan prozesatzen...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 atzetik</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Jasotako azken blokea duela %1 sortu zen.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Honen ondorengo transakzioak oraindik ez daude ikusgai.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Akatsa</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Abisua</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informazioa</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Eguneratua</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>Adabegiaren leihoa</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation>&amp;Helbideak bidaltzen</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation>&amp;Helbideak jasotzen</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation>Ireki bitcoin bat: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>Diruzorroa zabaldu</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation>Diruzorro bat zabaldu</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>Diruzorroa itxi...</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>Diruzorroa itxi</translation>
    </message>
    <message>
        <source>Close All Wallets...</source>
        <translation>Diruzorro guztiak itxi...</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>Diruzorro guztiak itxi</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation>Ez dago diru-zorrorik eskura</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Lehioa</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Txikitu</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Gerturatu</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation>Lehio nagusia</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 bezeroa</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>Pareekin konektatzen...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Eguneratzen...</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Akatsa: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>Abisua: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Data: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Kopurua: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation>Diruzorroa: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Mota: %1</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Etiketa: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Helbidea: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Bidalitako transakzioa</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Sartutako transakzioa</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>HD gakoa sortzea &lt;b&gt;gaituta&lt;/b&gt; dago</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>HD gakoa sortzea &lt;b&gt;desgaituta&lt;/b&gt; dago</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>Gako pribatua &lt;b&gt;desgaitua&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Zorroa &lt;b&gt;enkriptatuta&lt;/b&gt; eta &lt;b&gt;desblokeatuta&lt;/b&gt; dago une honetan</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Zorroa &lt;b&gt;enkriptatuta&lt;/b&gt; eta &lt;b&gt;blokeatuta&lt;/b&gt; dago une honetan</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation>Jatorrizko mezua:</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Txanpon aukeraketa</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Zenbat:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Byte kopurua:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Kopurua:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Ordainketa:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Hautsa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Ordaindu ondoren:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Bueltak:</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Zuhaitz modua</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Zerrenda modua</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kopurua</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Etiketarekin jasoa</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Helbidearekin jasoa</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Konfirmazioak</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Konfirmatuta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>zenbatekoaren kopia</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Etiketa kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;zenbatekoaren kopia</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Kopiatu transakzioaren IDa</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">&amp;Blokeatu erabili gabe</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;Desblokeatu gastatu gabe</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopia kopurua</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiatu byte-ak</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopiatu hautsa</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiatu aldaketa</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 blokeatuta)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>bai</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ez</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(izendapenik ez)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(bueltak)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation>Diruzorroa sortu</translation>
    </message>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
        <translation>Diruzorroa sortzen&lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation>Diruzorroa sortzen hutsegitea</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation>Diru-zorroa sortzearen buruzko oharra</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation>Diruzorroa sortu</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Diru-zorroa</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation>Diruzorroaren izena</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation>Diruzorroa enkriptatu</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation>Aukera aurreratuak</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation>Desgaitu gako pribatuak</translation>
    </message>
    <message>
        <source>Descriptor Wallet</source>
        <translation>Deskriptorearen zorroa</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Sortu</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Helbidea editatu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiketa</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Helbidea</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Bidaltzeko helbide berria</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Jasotzeko helbidea editatu</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Bidaltzeko helbidea editatu</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Ezin da diruzorroa desblokeatu.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Giltza berriaren sorrerak huts egin du.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>izena</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>bertsioa</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>%1 inguru</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Komando lerroaren aukerak</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Ongietorri</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Ongietorri %1-ra</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Akatsa</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Inprimakia</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation>Gainerako blokeen kopurua.</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>Ezezaguna...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Azken blokearen unea</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Aurrerapena</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>kalkulatzen...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Izkutatu</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Type</source>
        <comment>NetWatch: Type header</comment>
        <translation>Mota</translation>
    </message>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Helbidea</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open bitcoin URI</source>
        <translation>Ireki bitcoin URIa</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URI: </translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Arbeletik helbidea itsatsi</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open wallet failed</source>
        <translation>Diruzorroa irekitzen hutsegitea</translation>
    </message>
    <message>
        <source>Open wallet warning</source>
        <translation>Diruzorroa irekitzen abisua</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>Diruzorro lehenetsia</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation>Diruzorroa zabaldu</translation>
    </message>
    <message>
        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
        <translation>Diru-zorroa irekitzen &lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Aukerak</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Nagusia</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>Databasearen cache tamaina</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>Proxyaren IP helbidea  (IPv4: 127.0.0.1 / IPv6: ::1 adibidez )</translation>
    </message>
    <message>
        <source>&amp;Hide tray icon</source>
        <translation>&amp;Erretiluaren ikonoa ezkutatu</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation>Ireki konfigurazio fitxategia</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Bezeroaren aukera guztiak hasieratu.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Aukerak Hasieratu</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Sarea</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">&amp;Diruzorroa</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Aditu</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation>Diruaren &amp;kontrolaren ezaugarriak gaitu</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Portua mapeatu &amp;UPnP erabiliz</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation>Kanpoko konexioak onartu</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation>Sarbide konexioak baimendu</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>Proxyaren &amp;IP helbidea:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Portua:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Proxy portua (9050 adibidez)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Lehioa</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Pantaila</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Erabiltzaile-interfazearen &amp;hizkuntza:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>Zenbatekoa azaltzeko &amp;unitatea:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Ados</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Ezeztatu</translation>
    </message>
    <message>
        <source>default</source>
        <translation>lehenetsi</translation>
    </message>
    <message>
        <source>none</source>
        <translation>Bat ere ez</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Berretsi aukeren berrezarpena</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <translation>Bezeroa berrabiarazi behar da aldaketak aktibatzeko.</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <translation>Konfiguraketa aukerak</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Akatsa</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>Aldaketa honek clienta berriro piztea eskatzen du</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Inprimakia</translation>
    </message>
    <message>
        <source>Watch-only:</source>
        <translation>Ikusi-bakarrik:</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Eskuragarri:</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>Zai:</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Ez dago eskuragarri:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Guztira:</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Copy to Clipboard</source>
        <translation>Kopiatu arbelera</translation>
    </message>
    <message>
        <source>Save...</source>
        <translation>Gorde...</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Itxi</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>Ordainketa eskaera akatsa</translation>
    </message>
    <message>
        <source>Invalid payment address</source>
        <translation>Ordainketa helbide baliogabea</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <translation>Erabiltzaile agentea</translation>
    </message>
    <message>
        <source>Node/Service</source>
        <translation>Adabegi / Zerbitzua</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Mota</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Kopurua</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Akatsa: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ezezaguna</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;Informazioa</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">Sarea</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Diruzorroa: </translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation>Erabiltzaile agentea</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>Adabegiaren leihoa</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Azken blokearen unea</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Ra</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Tik</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>Network activity disabled</source>
        <translation>Sarea desaktibatua</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Ezezaguna</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Kopurua:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiketa:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Mezua:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Etiketa kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;zenbatekoaren kopia</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Ezin da diruzorroa desblokeatu.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Helbidea:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Kopurua:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Izendapen:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mezua:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Diruzorroa:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Helbidea kopiatu</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Izendapen</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mezua</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(izendapenik ez)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Txanponak bidali</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Zenbat:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Byte kopurua:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Kopurua:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Ordainketa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Ordaindu ondoren:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Bueltak:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">Aukeratu...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Izkutatu</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Hainbat jasotzaileri batera bidali</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Hautsa:</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Saldoa:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Bidalketa berretsi</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">&amp;Bidali</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopia kopurua</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>zenbatekoaren kopia</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiatu byte-ak</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopiatu hautsa</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiatu aldaketa</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Txanponen bidalketa berretsi</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Bidali</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Ordaintzeko kopurua, 0 baino handiagoa izan behar du.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(izendapenik ez)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>K&amp;opurua:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Ordaindu &amp;honi:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiketa:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Arbeletik helbidea itsatsi</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mezua:</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Honi ordaindu:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Arbeletik helbidea itsatsi</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>Mezua &amp;balioztatu</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">Mezua &amp;balioztatu</translation>
    </message>
    <message>
        <source>No error</source>
        <translation>Ez dago errorerik</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Errorea mezua sinatzean</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Mezua sinatuta.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Mesedez, begiratu sinadura eta saiatu berriro.</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Open until %1</source>
        <translation>Zabalik %1 arte</translation>
    </message>
    <message>
        <source>abandoned</source>
        <translation>abandonatuta</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/konfirmatu gabe</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 konfirmazio</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Egoera</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Iturria</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>Sortua</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Tik</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ezezaguna</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Ra</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>zure helbidea</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>ikusi bakarrik</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiketa</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Kreditua</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>Onartu gabe</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Zorrak</translation>
    </message>
    <message>
        <source>Total debit</source>
        <translation>Zor totala</translation>
    </message>
    <message>
        <source>Total credit</source>
        <translation>Kreditu totala</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mezua</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transakzioa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kopurua</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Panel honek transakzien deskribapen xehea azaltzen du</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Mota</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Izendapen</translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Zabalik %1 arte</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Konfirmatuta (%1 konfirmazio)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Sortua, baina ez onartua</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Honekin jasoa</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Hona bidalia</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Zure buruarentzat ordainketa</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Meatua</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>ikusi bakarrik</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(izendapenik ez)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Transakzioaren egoera. Pasatu sagua gainetik konfirmazio kopurua ikusteko.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Transakzioa jasotako data eta ordua.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Transakzio mota.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Saldoan kendu edo gehitutako kopurua.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Denak</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Gaurkoak</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Aste honetankoak</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Hil honetakoak</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Azken hilekoak</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Aurtengoak</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Muga...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Honekin jasoa</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Hona bidalia</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Meatua</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Beste</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Kopuru minimoa</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Etiketa kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;zenbatekoaren kopia</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Kopiatu transakzioaren IDa</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Komaz bereizitako artxiboa (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Berretsia</translation>
    </message>
    <message>
        <source>Watch-only</source>
        <translation type="unfinished">Ikusi-bakarrik</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Mota</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Izendapen</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Helbidea</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Esportazioak huts egin du</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished">Muga:</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>Diruzorroa itxi</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>Diruzorro guztiak itxi</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>Diruzorro berri bat sortu</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Akatsa</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Txanponak bidali</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>Diruzorro lehenetsia</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Esportatu</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Uneko fitxategian datuak esportatu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Ezeztatu</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>Akatsa</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Diru-zorroa kargatzen</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Birbilatzen...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Zamaketa amaitua</translation>
    </message>
</context>
</TS>